v0.5.0
======
* McChainSimulator (major) patch (#125)
* Update utilix version in requirements.txt (ffc6c2f)
* Don not track the timeout (#131)
* Change dtype of truth (#138)
* Load Rz field maps (#130)
* Conserve total quanta in tutorial (#135)
* Load GARFIELD map according to liquid level (#127)
* Fix PMT Afterpulse (#117)
* Fixing chunking issue (#118)
* Update history of releases (#123)
* Allow errors while building docs (#122)
* Fix missing epix import (#115)
* Fix non-literal compare (#121)
* Reintroduce self._electron_timings for truth (#116)
* Update tutorial notebook (f59c2c0 + ee6b6ad)

v0.4.1
======
* Miscellaneous fixes (#113)

v0.4.0
======
* S1+S2 functions are externally callable (#103)
* Docstrings for most functions (#103)
* Nveto QE implementation (#99)
* Functionality for full chain simulation (#111)
* Using epix for instruction clustering (#111)
* Website for documentation (#105)


v0.2.5
======
  * Config patch and debugging prints (#104)

v0.2.4
=======
  * First pip installable release


v0.0.1
=======

  * Release as a python package
